@@ -1,6 +1,6 @@
 from django.forms import ModelForm
 
-import models
+from . import models
 
 class UnitChangeForm(ModelForm):
     
