@@ -1,3 +1,5 @@
+from __future__ import print_function
+
 import urllib
 import os
 import re
@@ -58,9 +60,9 @@ class Command(BaseCommand):
             default=None),
         make_option('--quarter',
             default=None),
-        make_option('--dryrun',
-            action='store_true',
-            default=False),
+#         make_option('--dryrun',
+#             action='store_true',
+#             default=False),
         make_option('--force',
             action='store_true',
             default=False),
@@ -79,7 +81,7 @@ class Command(BaseCommand):
     
     def handle(self, **options):
         
-        self.dryrun = options['dryrun']
+#         self.dryrun = options['dryrun']
         self.force = options['force']
         self.verbose = options['verbose']
         
@@ -120,6 +122,7 @@ class Command(BaseCommand):
             processes = []
             self.status = Queue()
             for i, _ in enumerate(xrange(multi)):
+                print('Starting process %i' % i)
                 stripe = kwargs['stripe'] = '%i%i' % (i, multi)
                 kwargs['status'] = self.status
                 
@@ -138,7 +141,7 @@ class Command(BaseCommand):
                     if stripe not in self.start_times:
                         self.start_times[stripe] = time.time()
                     self.print_progress()
-            print 'All processes complete.'
+            print('All processes complete.')
         else:
             self.start_times[None] = time.time()
             self.run_process(**kwargs)
@@ -184,31 +187,33 @@ class Command(BaseCommand):
         for stripe, (current, total) in self.stripe_counts.iteritems():
             overall_current_count += current
             overall_total_count += total
-        #print 'overall_current_count:',overall_current_count
-        #print 'overall_total_count:',overall_total_count
+        #print('overall_current_count:',overall_current_count
+        #print('overall_total_count:',overall_total_count
         if overall_total_count and Job:
             Job.update_progress(
                 total_parts_complete=overall_current_count,
                 total_parts=overall_total_count,
             )
-            if not self.dryrun:
-                transaction.commit()
+#             if not self.dryrun:
+#                 transaction.commit()
     
     def run_process(self, status=None, **kwargs):
         tmp_debug = settings.DEBUG
         settings.DEBUG = False
-        transaction.enter_transaction_management()
-        transaction.managed(True)
+        #transaction.enter_transaction_management()
+        #transaction.managed(True)
         try:
+            print('Running process:', kwargs)
             self.import_attributes(status=status, **kwargs)
+            print('Done process:', kwargs)
         finally:
             settings.DEBUG = tmp_debug
-            if self.dryrun:
-                print 'This is a dryrun, so no changes were committed.'
-                transaction.rollback()
-            else:
-                transaction.commit()
-            transaction.leave_transaction_management()
+            #if self.dryrun:
+            #    print('This is a dryrun, so no changes were committed.'
+            #    transaction.rollback()
+            #else:
+            #    transaction.commit()
+            #transaction.leave_transaction_management()
             connection.close()
     
     def import_attributes(self, status=None, **kwargs):
@@ -224,7 +229,7 @@ class Command(BaseCommand):
         sub_total = 0
         
         def print_status(message, count=None, total=None):
-            #print 'message:',message
+            #print('message:',message
             current_count = count or 0
             total_count = total or 0
             if status:
@@ -238,7 +243,7 @@ class Command(BaseCommand):
                     message,
                 ])
             else:
-                #print 'total_count:',total_count
+                #print('total_count:',total_count
                 self.progress[stripe] = (
                     current_count,
                     total_count,
@@ -279,14 +284,17 @@ class Command(BaseCommand):
                     print>>sys.stderr, 'Warning: the company you specified with cik %s is not marked for loading.' % (self.cik,)
             
             if stripe is not None:
-                q = q.extra(where=['(("django_sec_index"."id" %%%% %i) = %i)' % (stripe_mod, stripe_num)])
+                #q = q.extra(where=['(("django_sec_index"."id" %%%% %i) = %i)' % (stripe_mod, stripe_num)])
+                q = q.extra(where=['((django_sec_index.id %%%% %i) = %i)' % (stripe_mod, stripe_num)])
                     
             #print_status('Finding total record count...')
+            #print('query:', q.query
             total_count = total = q.count()
+            print('total_count:', total_count)
             
             if kwargs['show_pending']:
-                print '='*80
-                print '%i total pending records' % total_count
+                print('='*80)
+                print('%i total pending records' % total_count)
                 return
             
             print_status('%i total rows.' % (total,))
@@ -297,17 +305,17 @@ class Command(BaseCommand):
                 i += 1
                 current_count = i
                 
-                #print 'Processing index %s for (%i of %i)' % (ifile.filename, i, total)
+                #print('Processing index %s for (%i of %i)' % (ifile.filename, i, total)
                 msg = 'Processing index %s.' % (ifile.filename,)
                 print_status(msg, count=i, total=total)
                 
                 if not i % commit_freq:
                     sys.stdout.flush()
-                    if not self.dryrun:
-                        transaction.commit()
+#                     if not self.dryrun:
+#                         transaction.commit()
                 
                 ifile.download(verbose=self.verbose)
-                #print 'xbrl link:',ifile.xbrl_link()
+                #print('xbrl link:',ifile.xbrl_link()
                 
                 # Initialize XBRL parser and populate an attribute called fields with
                 # a dict of 50 common terms.
@@ -315,7 +323,7 @@ class Command(BaseCommand):
                 error = None
                 try:
                     x = ifile.xbrl()
-                except Exception, e:
+                except Exception as e:
                     ferr = StringIO()
                     traceback.print_exc(file=ferr)
                     error = ferr.getvalue()
@@ -346,11 +354,11 @@ class Command(BaseCommand):
                             j += 1
                             sub_current = j
                             if not j % commit_freq:
-                                #print '\rImporting attribute %i of %i.' % (j, sub_total),
+                                #print('\rImporting attribute %i of %i.' % (j, sub_total),
                                 print_status(msg, count=i, total=total)
                                 #sys.stdout.flush()
-                                if not self.dryrun:
-                                    transaction.commit()
+#                                 if not self.dryrun:
+#                                     transaction.commit()
                                 
                             matches = re.findall('^\{([^\}]+)\}(.*)$', node.tag)
                             if matches:
@@ -383,6 +391,7 @@ class Command(BaseCommand):
                             if not attribute.load:
                                 continue
                             unit, _ = models.Unit.objects.get_or_create(name=node.attrib['unitRef'].strip())
+                            unit.save()
                             value = (node.text or '').strip()
                             if not value:
                                 continue
@@ -390,9 +399,9 @@ class Command(BaseCommand):
                                 'Value too large, must be less than %i digits: %i %s' \
                                     % (c.MAX_QUANTIZE, len(value), repr(value))
                             
-                            #print attribute
+                            #print(attribute
                             models.Attribute.objects.filter(id=attribute.id).update(total_values_fresh=False)
-                            #print context_id,attribute.name,node.attrib['decimals'],unit,start_date,end_date,ifile.date
+                            #print(context_id,attribute.name,node.attrib['decimals'],unit,start_date,end_date,ifile.date
                             
                             if models.AttributeValue.objects.filter(company=company, attribute=attribute, start_date=start_date).exists():
                                 continue
@@ -420,9 +429,9 @@ class Command(BaseCommand):
                                 bulk_objects = []
                                 prior_keys.clear()
                                 
-                        if not self.dryrun:
-                            transaction.commit()
-            #            print '\rImporting attribute %i of %i.' % (sub_total, sub_total),
+#                         if not self.dryrun:
+#                             transaction.commit()
+            #            print('\rImporting attribute %i of %i.' % (sub_total, sub_total),
             #            print
                         print_status('Importing attributes.', count=i, total=total)
                         
@@ -437,28 +446,29 @@ class Command(BaseCommand):
                         
                         models.Unit.do_update()
                         
-                        if not self.dryrun:
-                            transaction.commit()
+#                         if not self.dryrun:
+#                             transaction.commit()
                     
                         break
                     
-                    except DatabaseError, e:
+                    except DatabaseError as e:
                         if retry+1 == maxretries:
                             raise
-                        print e, 'retry', retry
+                        print(e, 'retry', retry)
                         connection.close()
                         time.sleep(random.random()*5)
                     
-                    except TransactionRollbackError, e:
+                    except TransactionRollbackError as e:
                         if TransactionRollbackError.__name__ != 'TransactionRollbackError':
                             raise
                         if retry+1 == maxretries:
                             raise
-                        print e, 'retry', retry
+                        print(e, 'retry', retry)
                         connection.close()
                         time.sleep(random.random()*5)
                     
-        except Exception, e:
+        except Exception as e:
+            print('Error: %s' % e)
             ferr = StringIO()
             traceback.print_exc(file=ferr)
             error = ferr.getvalue()
